==> istio-model-v1beta1-5.11.2-sources.jar: annotations/io/fabric8/istio/api/security/v1beta1/PeerAuthenticationSpecFluentImpl.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.istio.api.type.v1beta1.WorkloadSelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.LinkedHashMap;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelector;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder;

 /**
  * Generated
  */
public class PeerAuthenticationSpecFluentImpl<A extends io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent<A>{
  public PeerAuthenticationSpecFluentImpl() {
  }
  public PeerAuthenticationSpecFluentImpl(io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpec instance) {
    this.withMtls(instance.getMtls()); 
    this.withPortLevelMtls(instance.getPortLevelMtls()); 
    this.withSelector(instance.getSelector()); 
  }
  private io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLSBuilder mtls;
  private java.util.Map<java.lang.Long,io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS> portLevelMtls;
  private io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder selector;
  
  /**
   * This method has been deprecated, please use method buildMtls instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS getMtls() {
    return this.mtls!=null?this.mtls.build():null;
  }
  public io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS buildMtls() {
    return this.mtls!=null?this.mtls.build():null;
  }
  public A withMtls(io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS mtls) {
    _visitables.get("mtls").remove(this.mtls);
    if (mtls!=null){ this.mtls= new io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLSBuilder(mtls); _visitables.get("mtls").add(this.mtls);} return (A) this;
  }
  public java.lang.Boolean hasMtls() {
    return this.mtls != null;
  }
  public io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.MtlsNested<A> withNewMtls() {
    return new io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluentImpl.MtlsNestedImpl();
  }
  public io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.MtlsNested<A> withNewMtlsLike(io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS item) {
    return new io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluentImpl.MtlsNestedImpl(item);
  }
  public io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.MtlsNested<A> editMtls() {
    return withNewMtlsLike(getMtls());
  }
  public io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.MtlsNested<A> editOrNewMtls() {
    return withNewMtlsLike(getMtls() != null ? getMtls(): new io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLSBuilder().build());
  }
  public io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.MtlsNested<A> editOrNewMtlsLike(io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS item) {
    return withNewMtlsLike(getMtls() != null ? getMtls(): item);
  }
  public A addToPortLevelMtls(java.lang.Long key,io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS value) {
    if(this.portLevelMtls == null && key != null && value != null) { this.portLevelMtls = new java.util.LinkedHashMap<java.lang.Long,io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS>(); }
    if(key != null && value != null) {this.portLevelMtls.put(key, value);} return (A)this;
  }
  public A addToPortLevelMtls(java.util.Map<java.lang.Long,io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS> map) {
    if(this.portLevelMtls == null && map != null) { this.portLevelMtls = new java.util.LinkedHashMap<java.lang.Long,io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS>(); }
    if(map != null) { this.portLevelMtls.putAll(map);} return (A)this;
  }
  public A removeFromPortLevelMtls(java.lang.Long key) {
    if(this.portLevelMtls == null) { return (A) this; }
    if(key != null && this.portLevelMtls != null) {this.portLevelMtls.remove(key);} return (A)this;
  }
  public A removeFromPortLevelMtls(java.util.Map<java.lang.Long,io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS> map) {
    if(this.portLevelMtls == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.portLevelMtls != null){this.portLevelMtls.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.Long,io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS> getPortLevelMtls() {
    return this.portLevelMtls;
  }
  public <K,V>A withPortLevelMtls(java.util.Map<java.lang.Long,io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS> portLevelMtls) {
    if (portLevelMtls == null) { this.portLevelMtls =  null;} else {this.portLevelMtls = new java.util.LinkedHashMap<java.lang.Long,io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS>(portLevelMtls);} return (A) this;
  }
  public java.lang.Boolean hasPortLevelMtls() {
    return this.portLevelMtls != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.istio.api.type.v1beta1.WorkloadSelector getSelector() {
    return this.selector!=null?this.selector.build():null;
  }
  public io.fabric8.istio.api.type.v1beta1.WorkloadSelector buildSelector() {
    return this.selector!=null?this.selector.build():null;
  }
  public A withSelector(io.fabric8.istio.api.type.v1beta1.WorkloadSelector selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder(selector); _visitables.get("selector").add(this.selector);} return (A) this;
  }
  public java.lang.Boolean hasSelector() {
    return this.selector != null;
  }
  public io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.TypeSelectorNested<A> withNewTypeSelector() {
    return new io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluentImpl.TypeSelectorNestedImpl();
  }
  public io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.TypeSelectorNested<A> withNewSelectorLike(io.fabric8.istio.api.type.v1beta1.WorkloadSelector item) {
    return new io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluentImpl.TypeSelectorNestedImpl(item);
  }
  public io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.TypeSelectorNested<A> editTypeSelector() {
    return withNewSelectorLike(getSelector());
  }
  public io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.TypeSelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(getSelector() != null ? getSelector(): new io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder().build());
  }
  public io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.TypeSelectorNested<A> editOrNewSelectorLike(io.fabric8.istio.api.type.v1beta1.WorkloadSelector item) {
    return withNewSelectorLike(getSelector() != null ? getSelector(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PeerAuthenticationSpecFluentImpl that = (PeerAuthenticationSpecFluentImpl) o;
    if (mtls != null ? !mtls.equals(that.mtls) :that.mtls != null) return false;
    if (portLevelMtls != null ? !portLevelMtls.equals(that.portLevelMtls) :that.portLevelMtls != null) return false;
    if (selector != null ? !selector.equals(that.selector) :that.selector != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(mtls,  portLevelMtls,  selector,  super.hashCode());
  }
  public class MtlsNestedImpl<N> extends io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLSFluentImpl<io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.MtlsNested<N>> implements io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.MtlsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MtlsNestedImpl(io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS item) {
      this.builder = new io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLSBuilder(this, item);
    }
    MtlsNestedImpl() {
      this.builder = new io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLSBuilder(this);
    }
    io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLSBuilder builder;
    public N and() {
      return (N) PeerAuthenticationSpecFluentImpl.this.withMtls(builder.build());
    }
    public N endMtls() {
      return and();
    }
    
  }
  public class TypeSelectorNestedImpl<N> extends io.fabric8.istio.api.type.v1beta1.WorkloadSelectorFluentImpl<io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.TypeSelectorNested<N>> implements io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.TypeSelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TypeSelectorNestedImpl(io.fabric8.istio.api.type.v1beta1.WorkloadSelector item) {
      this.builder = new io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder(this, item);
    }
    TypeSelectorNestedImpl() {
      this.builder = new io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder(this);
    }
    io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder builder;
    public N and() {
      return (N) PeerAuthenticationSpecFluentImpl.this.withSelector(builder.build());
    }
    public N endTypeSelector() {
      return and();
    }
    
  }
  
}

==> istio-model-v1beta1-5.12.0-sources.jar: annotations/io/fabric8/istio/api/security/v1beta1/PeerAuthenticationSpecFluentImpl.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.istio.api.type.v1beta1.WorkloadSelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.LinkedHashMap;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelector;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder;

 /**
  * Generated
  */
public class PeerAuthenticationSpecFluentImpl<A extends io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent<A>{
  public PeerAuthenticationSpecFluentImpl() {
  }
  public PeerAuthenticationSpecFluentImpl(io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpec instance) {
    this.withMtls(instance.getMtls()); 
    this.withPortLevelMtls(instance.getPortLevelMtls()); 
    this.withSelector(instance.getSelector()); 
  }
  private io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLSBuilder mtls;
  private java.util.Map<java.lang.Long,io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS> portLevelMtls;
  private io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder selector;
  
  /**
   * This method has been deprecated, please use method buildMtls instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS getMtls() {
    return this.mtls!=null?this.mtls.build():null;
  }
  public io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS buildMtls() {
    return this.mtls!=null?this.mtls.build():null;
  }
  public A withMtls(io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS mtls) {
    _visitables.get("mtls").remove(this.mtls);
    if (mtls!=null){ this.mtls= new io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLSBuilder(mtls); _visitables.get("mtls").add(this.mtls);} return (A) this;
  }
  public java.lang.Boolean hasMtls() {
    return this.mtls != null;
  }
  public io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.MtlsNested<A> withNewMtls() {
    return new io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluentImpl.MtlsNestedImpl();
  }
  public io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.MtlsNested<A> withNewMtlsLike(io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS item) {
    return new io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluentImpl.MtlsNestedImpl(item);
  }
  public io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.MtlsNested<A> editMtls() {
    return withNewMtlsLike(getMtls());
  }
  public io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.MtlsNested<A> editOrNewMtls() {
    return withNewMtlsLike(getMtls() != null ? getMtls(): new io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLSBuilder().build());
  }
  public io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.MtlsNested<A> editOrNewMtlsLike(io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS item) {
    return withNewMtlsLike(getMtls() != null ? getMtls(): item);
  }
  public A addToPortLevelMtls(java.lang.Long key,io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS value) {
    if(this.portLevelMtls == null && key != null && value != null) { this.portLevelMtls = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.portLevelMtls.put(key, value);} return (A)this;
  }
  public A addToPortLevelMtls(java.util.Map<java.lang.Long,io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS> map) {
    if(this.portLevelMtls == null && map != null) { this.portLevelMtls = new java.util.LinkedHashMap(); }
    if(map != null) { this.portLevelMtls.putAll(map);} return (A)this;
  }
  public A removeFromPortLevelMtls(java.lang.Long key) {
    if(this.portLevelMtls == null) { return (A) this; }
    if(key != null && this.portLevelMtls != null) {this.portLevelMtls.remove(key);} return (A)this;
  }
  public A removeFromPortLevelMtls(java.util.Map<java.lang.Long,io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS> map) {
    if(this.portLevelMtls == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.portLevelMtls != null){this.portLevelMtls.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.Long,io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS> getPortLevelMtls() {
    return this.portLevelMtls;
  }
  public <K,V>A withPortLevelMtls(java.util.Map<java.lang.Long,io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS> portLevelMtls) {
    if (portLevelMtls == null) { this.portLevelMtls =  null;} else {this.portLevelMtls = new java.util.LinkedHashMap(portLevelMtls);} return (A) this;
  }
  public java.lang.Boolean hasPortLevelMtls() {
    return this.portLevelMtls != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.istio.api.type.v1beta1.WorkloadSelector getSelector() {
    return this.selector!=null?this.selector.build():null;
  }
  public io.fabric8.istio.api.type.v1beta1.WorkloadSelector buildSelector() {
    return this.selector!=null?this.selector.build():null;
  }
  public A withSelector(io.fabric8.istio.api.type.v1beta1.WorkloadSelector selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder(selector); _visitables.get("selector").add(this.selector);} return (A) this;
  }
  public java.lang.Boolean hasSelector() {
    return this.selector != null;
  }
  public io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.TypeSelectorNested<A> withNewTypeSelector() {
    return new io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluentImpl.TypeSelectorNestedImpl();
  }
  public io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.TypeSelectorNested<A> withNewSelectorLike(io.fabric8.istio.api.type.v1beta1.WorkloadSelector item) {
    return new io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluentImpl.TypeSelectorNestedImpl(item);
  }
  public io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.TypeSelectorNested<A> editTypeSelector() {
    return withNewSelectorLike(getSelector());
  }
  public io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.TypeSelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(getSelector() != null ? getSelector(): new io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder().build());
  }
  public io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.TypeSelectorNested<A> editOrNewSelectorLike(io.fabric8.istio.api.type.v1beta1.WorkloadSelector item) {
    return withNewSelectorLike(getSelector() != null ? getSelector(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PeerAuthenticationSpecFluentImpl that = (PeerAuthenticationSpecFluentImpl) o;
    if (mtls != null ? !mtls.equals(that.mtls) :that.mtls != null) return false;
    if (portLevelMtls != null ? !portLevelMtls.equals(that.portLevelMtls) :that.portLevelMtls != null) return false;
    if (selector != null ? !selector.equals(that.selector) :that.selector != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(mtls,  portLevelMtls,  selector,  super.hashCode());
  }
  public class MtlsNestedImpl<N> extends io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLSFluentImpl<io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.MtlsNested<N>> implements io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.MtlsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MtlsNestedImpl(io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLS item) {
      this.builder = new io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLSBuilder(this, item);
    }
    MtlsNestedImpl() {
      this.builder = new io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLSBuilder(this);
    }
    io.fabric8.istio.api.security.v1beta1.PeerAuthenticationMutualTLSBuilder builder;
    public N and() {
      return (N) PeerAuthenticationSpecFluentImpl.this.withMtls(builder.build());
    }
    public N endMtls() {
      return and();
    }
    
  }
  public class TypeSelectorNestedImpl<N> extends io.fabric8.istio.api.type.v1beta1.WorkloadSelectorFluentImpl<io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.TypeSelectorNested<N>> implements io.fabric8.istio.api.security.v1beta1.PeerAuthenticationSpecFluent.TypeSelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TypeSelectorNestedImpl(io.fabric8.istio.api.type.v1beta1.WorkloadSelector item) {
      this.builder = new io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder(this, item);
    }
    TypeSelectorNestedImpl() {
      this.builder = new io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder(this);
    }
    io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder builder;
    public N and() {
      return (N) PeerAuthenticationSpecFluentImpl.this.withSelector(builder.build());
    }
    public N endTypeSelector() {
      return and();
    }
    
  }
  
}
